% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/subscore.s.r
\name{subscore.s}
\alias{subscore.s}
\title{Computing subscores using Haberman's method based on observed subscores.}
\usage{
subscore.s(test.data)
}
\arguments{
\item{test.data}{A list that contains item responses of all subtests and 
the entire test, which can be obtained using function 'data.prep'.}
}
\value{
\item{summary}{Summary of obtained subscores (e.g., mean, sd).}
\item{PRMSE}{PRMSEs of obtained subscores (for Haberman's methods only).}
\item{subscore.original}{Original subscores and total score.}
\item{subscore.s}{Subscores that are estimated based on the observed subscore.}
}
\description{
This function estimate true subscores based on observed subscores, 
using the method introduced by Haberman (2008) <doi:10.3102/1076998607302636>.
}
\examples{
# Transferring scored response data to the required list format
test.data<-data.prep(scored.data,c(3,15,15,20),
                     c("Algebra","Geometry","Measurement", "Math"))
  
# Estimate true subscores using Haberman's method based on observed subscores     
subscore.s(test.data) 
       
subscore.s(test.data)$summary
subscore.s(test.data)$Correlation
subscore.s(test.data)$Disattenuated.correlation
subscore.s(test.data)$PRMSE
subscore.s(test.data)$subscore.s
}
\references{
{
Haberman, S. J. (2008). 
"When can subscores have value?."
 Journal of Educational and Behavioral Statistics, 33(2), 204-229. doi:10.3102/1076998607302636.
}
}
